@@ -223,3 +223,62 @@ class Nationality(Base):
 
     def __str__(self):
         return self.name_ru
+
+
+class Grant(Base):
+    """
+    Грант студента
+    """
+    __tablename__ = 'univer_grant'
+
+    # Идентификатор
+    id = Column('grant_id', Integer, primary_key=True)
+
+    # Дата назначения гранта
+    date_recieved = Column('grant_date_recieved', DateTime)
+
+    # Номер гранта
+    number = Column('grant_number', String(15))
+
+    # Студент
+    student_id = Column(ForeignKey('univer_students.students_id'))
+    student = relationship('Student')
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<Grant {} (id={} student={} status={})>'.format(self, self.id, self.student_id, self.status)
+
+    def __str__(self):
+        return f'Грант - {self.student}: {self.number} ({self.date_recieved})'
+
+
+class Contract(Base):
+    """
+    Договор студента
+    """
+    __tablename__ = 'univer_contract'
+
+    # Идентификатор
+    id = Column('contract_id', Integer, primary_key=True)
+
+    # Номер договора
+    number = Column('contract_number', String(50))
+
+    # Дата начало договора
+    date_recieved = Column('contract_date_recieved', DateTime)
+
+    # Студент
+    student_id = Column('students_id', ForeignKey(
+        'univer_students.students_id'))
+    student = relationship('Student')
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<Contract {} (id={} student={} status={})>'.format(self, self.id, self.student_id, self.status)
+
+    def __str__(self):
+        return f'Договор - {self.student}: {self.number} ({self.date_recieved})'
